@@ -13,6 +13,8 @@ import textwrap
 from functools import partial
 from urllib.parse import urlparse
 
+from landscape.client import GROUP
+from landscape.client import USER
 from landscape.client.broker.amp import RemoteBrokerConnector
 from landscape.client.broker.config import BrokerConfiguration
 from landscape.client.broker.registration import Identity
@@ -197,14 +199,15 @@ class LandscapeSetupConfiguration(BrokerConfiguration):
             "--script-users",
             metavar="USERS",
             help="A comma-separated list of users to allow "
-            "scripts to run.  To allow scripts to be run "
+            "scripts to run. To allow scripts to be run "
             "by any user, enter: ALL",
         )
         parser.add_option(
             "--include-manager-plugins",
             metavar="PLUGINS",
             default="",
-            help="A comma-separated list of manager plugins to " "load.",
+            help="A comma-separated list of manager plugins "
+            "to enable in addition to the defaults.",
         )
         parser.add_option(
             "-n",
@@ -228,13 +231,13 @@ class LandscapeSetupConfiguration(BrokerConfiguration):
             "--disable",
             action="store_true",
             default=False,
-            help="Stop running clients and disable start at " "boot.",
+            help="Stop running clients and disable start at boot.",
         )
         parser.add_option(
             "--init",
             action="store_true",
             default=False,
-            help="Set up the client directories structure " "and exit.",
+            help="Set up the client directories structure and exit.",
         )
         parser.add_option(
             "--is-registered",
@@ -565,7 +568,7 @@ def check_account_name_and_password(config):
     if config.silent and not config.no_start:
         if not (config.get("account_name") and config.get("computer_title")):
             raise ConfigurationError(
-                "An account name and computer title are " "required.",
+                "An account name and computer title are required.",
             )
 
 
@@ -624,8 +627,10 @@ def setup(config):
     decode_base64_ssl_public_certificate(config)
     config.write()
     # Restart the client to ensure that it's using the new configuration.
+
     if not config.no_start:
         try:
+            set_secure_id(config, "registering")
             ServiceConfig.restart_landscape()
         except ServiceConfigException as exc:
             print_text(str(exc), error=True)
@@ -643,13 +648,8 @@ def setup(config):
 def bootstrap_tree(config):
     """Create the client directories tree."""
     bootstrap_list = [
-        BootstrapDirectory("$data_path", "landscape", "root", 0o755),
-        BootstrapDirectory(
-            "$annotations_path",
-            "landscape",
-            "landscape",
-            0o755,
-        ),
+        BootstrapDirectory("$data_path", USER, "root", 0o755),
+        BootstrapDirectory("$annotations_path", USER, GROUP, 0o755),
     ]
     BootstrapList(bootstrap_list).bootstrap(
         data_path=config.data_path,
@@ -796,13 +796,14 @@ def register(
     # Results will be things like "success" or "ssl-error".
     result = results[0]
 
-    if isinstance(result, SystemExit):
-        raise result
-
     # If there was an error and the caller requested that errors be reported
     # to the on_error callable, then do so.
     if result != "success" and on_error is not None:
         on_error(1)
+
+    if isinstance(result, SystemExit):
+        raise result
+
     return result
 
 
@@ -883,6 +884,21 @@ def registration_info_text(config, registration_status):
     return text
 
 
+def set_secure_id(config, new_id):
+    """Persists a secure id in the identity data file. This is used to indicate
+    whether we are currently in the process of registering.
+    """
+    persist = Persist(
+        filename=os.path.join(
+            config.data_path,
+            f"{BrokerService.service_name}.bpickle",
+        ),
+    )
+    identity = Identity(config, persist)
+    identity.secure_id = new_id
+    persist.save()
+
+
 def main(args, print=print):
     """Interact with the user and the server to set up client configuration."""
 
@@ -927,7 +943,11 @@ def main(args, print=print):
     # Attempt to register the client.
     reactor = LandscapeReactor()
     if config.silent:
-        result = register(config, reactor)
+        result = register(
+            config,
+            reactor,
+            on_error=lambda _: set_secure_id(config, None),
+        )
         report_registration_outcome(result, print=print)
         sys.exit(determine_exit_code(result))
     else:
@@ -937,6 +957,10 @@ def main(args, print=print):
             default=default_answer,
         )
         if answer:
-            result = register(config, reactor)
+            result = register(
+                config,
+                reactor,
+                on_error=lambda _: set_secure_id(config, None),
+            )
             report_registration_outcome(result, print=print)
             sys.exit(determine_exit_code(result))
