@@ -20,10 +20,10 @@ ALL_PLUGINS = [
     "SwiftUsage",
     "CephUsage",
     "ComputerTags",
-    "UbuntuProInfo",
     "LivePatch",
     "UbuntuProRebootRequired",
     "SnapMonitor",
+    "SnapServicesMonitor",
 ]
 
 
