@@ -39,7 +39,6 @@ class ReleaseUpgraderConfigurationTest(unittest.TestCase):
 
 
 class ReleaseUpgraderTest(LandscapeTest):
-
     helpers = [LogKeeperHelper, EnvironSaverHelper, BrokerServiceHelper]
 
     def setUp(self):
@@ -357,7 +356,6 @@ class ReleaseUpgraderTest(LandscapeTest):
         deferred = Deferred()
 
         def do_test():
-
             result = self.upgrader.upgrade("karmic", 100)
 
             def check_result(ignored):
@@ -391,7 +389,8 @@ class ReleaseUpgraderTest(LandscapeTest):
         reactor.callWhenRunning(do_test)
 
         def cleanup(ignored):
-            os.environ = env_backup
+            os.environ.clear()
+            os.environ.update(env_backup)
             return ignored
 
         return deferred.addBoth(cleanup)
@@ -418,7 +417,6 @@ class ReleaseUpgraderTest(LandscapeTest):
         deferred = Deferred()
 
         def do_test():
-
             result = self.upgrader.upgrade(
                 "karmic",
                 100,
@@ -451,7 +449,8 @@ class ReleaseUpgraderTest(LandscapeTest):
         reactor.callWhenRunning(do_test)
 
         def cleanup(ignored):
-            os.environ = env_backup
+            os.environ.clear()
+            os.environ.update(env_backup)
             return ignored
 
         return deferred.addBoth(cleanup)
@@ -472,7 +471,6 @@ class ReleaseUpgraderTest(LandscapeTest):
         deferred = Deferred()
 
         def do_test():
-
             result = self.upgrader.upgrade("karmic", 100)
 
             def check_result(ignored):
@@ -538,7 +536,6 @@ class ReleaseUpgraderTest(LandscapeTest):
         deferred = Deferred()
 
         def do_test():
-
             result = self.upgrader.upgrade("karmic", 100)
 
             def kill_child(how):
@@ -756,8 +753,8 @@ class ReleaseUpgraderTest(LandscapeTest):
         self.upgrader.upgrade = upgrade
         self.upgrader.finish = finish
 
-        self.upgrader.lsb_release_filename = self.makeFile(
-            "DISTRIB_CODENAME=jaunty\n",
+        self.upgrader.os_release_filename = self.makeFile(
+            "VERSION_CODENAME=jaunty\n",
         )
 
         message = {
@@ -785,8 +782,8 @@ class ReleaseUpgraderTest(LandscapeTest):
         The L{ReleaseUpgrader.handle_release_upgrade} method reports a
         failure if the system is already running the desired release.
         """
-        self.upgrader.lsb_release_filename = self.makeFile(
-            "DISTRIB_CODENAME=karmic\n",
+        self.upgrader.os_release_filename = self.makeFile(
+            "VERSION_CODENAME=karmic\n",
         )
 
         message = {
@@ -825,8 +822,8 @@ class ReleaseUpgraderTest(LandscapeTest):
         The L{ReleaseUpgrader.handle_release_upgrade} method reports a
         failure if any of the helper method errbacks.
         """
-        self.upgrader.lsb_release_filename = self.makeFile(
-            "DISTRIB_CODENAME=jaunty\n",
+        self.upgrader.os_release_filename = self.makeFile(
+            "VERSION_CODENAME=jaunty\n",
         )
 
         calls = []
