@@ -18,15 +18,24 @@
 # along with this Python module; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-import os
-import sys
 import copy
+import os
 import re
+import sys
+
+from twisted.python.compat import StringType  # Py2: basestring, Py3: str
 
 
-__all__ = ["Persist", "PickleBackend", "BPickleBackend",
-           "path_string_to_tuple", "path_tuple_to_string", "RootedPersist",
-           "PersistError", "PersistReadOnlyError"]
+__all__ = [
+    "Persist",
+    "PickleBackend",
+    "BPickleBackend",
+    "path_string_to_tuple",
+    "path_tuple_to_string",
+    "RootedPersist",
+    "PersistError",
+    "PersistReadOnlyError",
+]
 
 
 NOTHING = object()
@@ -40,7 +49,7 @@ class PersistReadOnlyError(PersistError):
     pass
 
 
-class Persist(object):
+class Persist:
 
     """Persist a hierarchical database of key=>value pairs.
 
@@ -109,15 +118,19 @@ class Persist(object):
 
         def load_old():
             filepathold = filepath + ".old"
-            if (os.path.isfile(filepathold) and
-                os.path.getsize(filepathold) > 0):
-                # warning("Broken configuration file at %s" % filepath)
-                # warning("Trying backup at %s" % filepathold)
+            if (
+                os.path.isfile(filepathold)
+                and os.path.getsize(filepathold) > 0
+            ):
+
+                # warning(f"Broken configuration file at {filepath}")
+                # warning(f"Trying backup at {filepathold}")
                 try:
                     self._hardmap = self._backend.load(filepathold)
-                except:
-                    raise PersistError("Broken configuration file at %s" %
-                                       filepathold)
+                except Exception:
+                    raise PersistError(
+                        f"Broken configuration file at {filepathold}",
+                    )
                 return True
             return False
 
@@ -125,16 +138,16 @@ class Persist(object):
         if not os.path.isfile(filepath):
             if load_old():
                 return
-            raise PersistError("File not found: %s" % filepath)
+            raise PersistError(f"File not found: {filepath}")
         if os.path.getsize(filepath) == 0:
             load_old()
             return
         try:
             self._hardmap = self._backend.load(filepath)
-        except:
+        except Exception:
             if load_old():
                 return
-            raise PersistError("Broken configuration file at %s" % filepath)
+            raise PersistError(f"Broken configuration file at {filepath}")
 
     def save(self, filepath=None):
         """Save the persist to the given C{filepath}.
@@ -169,10 +182,11 @@ class Persist(object):
             newobj = self._backend.get(obj, elem)
             if newobj is NotImplemented:
                 if queue:
-                    path = path[:-len(queue)]
-                raise PersistError("Can't traverse %r (%r): %r" %
-                                   (type(obj), path_tuple_to_string(path),
-                                    str(obj)))
+                    path = path[: -len(queue)]
+                raise PersistError(
+                    f"Can't traverse {type(obj)!r} "
+                    f"({path_tuple_to_string(path)!r}): {str(obj)!r}",
+                )
             if newobj is marker:
                 break
         if newobj is not marker:
@@ -192,8 +206,10 @@ class Persist(object):
                         newvalue = setvalue
                     newobj = self._backend.set(obj, elem, newvalue)
                     if newobj is NotImplemented:
-                        raise PersistError("Can't traverse %r with %r" %
-                                           (type(obj), type(elem)))
+                        raise PersistError(
+                            f"Can't traverse {type(obj)!r} "
+                            f"with {type(elem)!r}",
+                        )
                     if not queue:
                         break
                     obj = newobj
@@ -201,7 +217,7 @@ class Persist(object):
         return newobj
 
     def _getvalue(self, path, soft=False, hard=False, weak=False):
-        if type(path) is str:
+        if isinstance(path, StringType):
             path = path_string_to_tuple(path)
         marker = NOTHING
         if soft:
@@ -227,7 +243,7 @@ class Persist(object):
             return True
         result = self._backend.has(obj, value)
         if result is NotImplemented:
-            raise PersistError("Can't check %r for containment" % type(obj))
+            raise PersistError(f"Can't check {type(obj)!r} for containment")
         return result
 
     def keys(self, path, soft=False, hard=False, weak=False):
@@ -236,7 +252,7 @@ class Persist(object):
             return []
         result = self._backend.keys(obj)
         if result is NotImplemented:
-            raise PersistError("Can't return keys for %s" % type(obj))
+            raise PersistError(f"Can't return keys for {type(obj)}")
         return result
 
     def get(self, path, default=None, soft=False, hard=False, weak=False):
@@ -247,7 +263,7 @@ class Persist(object):
 
     def set(self, path, value, soft=False, weak=False):
         assert path
-        if type(path) is str:
+        if isinstance(path, StringType):
             path = path_string_to_tuple(path)
         if soft:
             map = self._softmap
@@ -261,7 +277,7 @@ class Persist(object):
 
     def add(self, path, value, unique=False, soft=False, weak=False):
         assert path
-        if type(path) is str:
+        if isinstance(path, StringType):
             path = path_string_to_tuple(path)
         if soft:
             map = self._softmap
@@ -275,12 +291,12 @@ class Persist(object):
             current = self._traverse(map, path)
             if type(current) is list and value in current:
                 return
-        path = path + (sys.maxint,)
+        path = path + (sys.maxsize,)
         self._traverse(map, path, setvalue=value)
 
     def remove(self, path, value=NOTHING, soft=False, weak=False):
         assert path
-        if type(path) is str:
+        if isinstance(path, StringType):
             path = path_string_to_tuple(path)
         if soft:
             map = self._softmap
@@ -304,8 +320,9 @@ class Persist(object):
             if obj is not marker:
                 result = self._backend.remove(obj, elem, isvalue)
                 if result is NotImplemented:
-                    raise PersistError("Can't remove %r from %r" %
-                                       (elem, type(obj)))
+                    raise PersistError(
+                        "Can't remove {!r} from {!r}".format(elem, type(obj)),
+                    )
             if self._backend.empty(obj):
                 if value is not marker:
                     value = marker
@@ -318,9 +335,9 @@ class Persist(object):
     def move(self, oldpath, newpath, soft=False, weak=False):
         if not (soft or weak):
             self.assert_writable()
-        if type(oldpath) is str:
+        if isinstance(oldpath, StringType):
             oldpath = path_string_to_tuple(oldpath)
-        if type(newpath) is str:
+        if isinstance(newpath, StringType):
             newpath = path_string_to_tuple(newpath)
         result = False
         marker = NOTHING
@@ -340,7 +357,7 @@ class Persist(object):
         return RootedPersist(self, path)
 
 
-class RootedPersist(object):
+class RootedPersist:
     """Root a L{Persist}'s tree at a particular branch.
 
     This class shares the same interface of L{Persist} and provides a shortcut
@@ -358,7 +375,7 @@ class RootedPersist(object):
             will be used as root of this L{RootedPersist}.
         """
         self.parent = parent
-        if type(root) is str:
+        if isinstance(root, StringType):
             self.root = path_string_to_tuple(root)
         else:
             self.root = root
@@ -370,45 +387,49 @@ class RootedPersist(object):
         self.parent.assert_writable()
 
     def has(self, path, value=NOTHING, soft=False, hard=False, weak=False):
-        if type(path) is str:
+        if isinstance(path, StringType):
             path = path_string_to_tuple(path)
         return self.parent.has(self.root + path, value, soft, hard, weak)
 
     def keys(self, path, soft=False, hard=False, weak=False):
-        if type(path) is str:
+        if isinstance(path, StringType):
             path = path_string_to_tuple(path)
         return self.parent.keys(self.root + path, soft, hard, weak)
 
     def get(self, path, default=None, soft=False, hard=False, weak=False):
-        if type(path) is str:
+        if isinstance(path, StringType):
             path = path_string_to_tuple(path)
         return self.parent.get(self.root + path, default, soft, hard, weak)
 
     def set(self, path, value, soft=False, weak=False):
-        if type(path) is str:
+        if isinstance(path, StringType):
             path = path_string_to_tuple(path)
         return self.parent.set(self.root + path, value, soft, weak)
 
     def add(self, path, value, unique=False, soft=False, weak=False):
-        if type(path) is str:
+        if isinstance(path, StringType):
             path = path_string_to_tuple(path)
         return self.parent.add(self.root + path, value, unique, soft, weak)
 
     def remove(self, path, value=NOTHING, soft=False, weak=False):
-        if type(path) is str:
+        if isinstance(path, StringType):
             path = path_string_to_tuple(path)
         return self.parent.remove(self.root + path, value, soft, weak)
 
     def move(self, oldpath, newpath, soft=False, weak=False):
-        if type(oldpath) is str:
+        if isinstance(oldpath, StringType):
             oldpath = path_string_to_tuple(oldpath)
-        if type(newpath) is str:
+        if isinstance(newpath, StringType):
             newpath = path_string_to_tuple(newpath)
-        return self.parent.move(self.root + oldpath, self.root + newpath,
-                                soft, weak)
+        return self.parent.move(
+            self.root + oldpath,
+            self.root + newpath,
+            soft,
+            weak,
+        )
 
     def root_at(self, path):
-        if type(path) is str:
+        if isinstance(path, StringType):
             path = path_string_to_tuple(path)
         return self.parent.root_at(self.root + path)
 
@@ -442,7 +463,7 @@ def path_string_to_tuple(path):
                 try:
                     result.append(int(token[1:-1]))
                 except ValueError:
-                    raise PersistError("Invalid path index: %r" % token)
+                    raise PersistError(f"Invalid path index: {token!r}")
             else:
                 result.append(token.replace(r"\.", "."))
     return tuple(result)
@@ -452,13 +473,13 @@ def path_tuple_to_string(path):
     result = []
     for elem in path:
         if type(elem) is int:
-            result[-1] += "[%d]" % elem
+            result[-1] += f"[{elem:d}]"
         else:
-            result.append(str(elem).replace(".", "\."))
+            result.append(str(elem).replace(".", r"\."))
     return ".".join(result)
 
 
-class Backend(object):
+class Backend:
     """
     Base class for L{Persist} backends implementing hierarchical storage
     functionality.
@@ -479,6 +500,7 @@ class Backend(object):
 
     For example:
 
+        >>> backend = Backend()
         >>> root = backend.new()
         >>> backend.set(root, "foo", "bar")
         'bar'
@@ -567,7 +589,7 @@ class Backend(object):
 
     def empty(self, obj):
         """Whether the given node object has no children."""
-        return (not obj)
+        return not obj
 
     def has(self, obj, elem):
         """Whether the given node object contains the given child element."""
@@ -587,50 +609,39 @@ class Backend(object):
 
 
 class PickleBackend(Backend):
-
     def __init__(self):
-        import cPickle
+        from landscape.lib.compat import cPickle
+
         self._pickle = cPickle
 
     def new(self):
         return {}
 
     def load(self, filepath):
-        file = open(filepath)
-        try:
-            return self._pickle.load(file)
-        finally:
-            file.close()
+        with open(filepath, "rb") as fd:
+            return self._pickle.load(fd)
 
     def save(self, filepath, map):
-        file = open(filepath, "w")
-        try:
-            self._pickle.dump(map, file, 2)
-        finally:
-            file.close()
+        with open(filepath, "wb") as fd:
+            self._pickle.dump(map, fd, 2)
 
 
 class BPickleBackend(Backend):
-
     def __init__(self):
         from landscape.lib import bpickle
+
         self._bpickle = bpickle
 
     def new(self):
         return {}
 
     def load(self, filepath):
-        file = open(filepath)
-        try:
-            return self._bpickle.loads(file.read())
-        finally:
-            file.close()
+        with open(filepath, "rb") as fd:
+            return self._bpickle.loads(fd.read())
 
     def save(self, filepath, map):
-        file = open(filepath, "w")
-        try:
-            file.write(self._bpickle.dumps(map))
-        finally:
-            file.close()
+        with open(filepath, "wb") as fd:
+            fd.write(self._bpickle.dumps(map))
+
 
 # vim:ts=4:sw=4:et
