@@ -1,20 +1,22 @@
 import os
-from threading import local
 import unittest
+from threading import local
 
 import pycurl
-
 from twisted.internet.defer import FirstError
 from twisted.python.compat import unicode
 
 from landscape.lib import testing
-from landscape.lib.fetch import (
-    fetch, fetch_async, fetch_many_async, fetch_to_files,
-    url_to_filename, HTTPCodeError, PyCurlError)
+from landscape.lib.fetch import fetch
+from landscape.lib.fetch import fetch_async
+from landscape.lib.fetch import fetch_many_async
+from landscape.lib.fetch import fetch_to_files
+from landscape.lib.fetch import HTTPCodeError
+from landscape.lib.fetch import PyCurlError
+from landscape.lib.fetch import url_to_filename
 
 
-class CurlStub(object):
-
+class CurlStub:
     def __init__(self, result=None, infos=None, error=None):
         self.result = result
         self.infos = infos
@@ -27,7 +29,7 @@ class CurlStub(object):
     def getinfo(self, what):
         if what in self.infos:
             return self.infos[what]
-        raise RuntimeError("Stub doesn't know about %d info" % what)
+        raise RuntimeError(f"Stub doesn't know about {what:d} info")
 
     def setopt(self, option, value):
         if isinstance(value, unicode):
@@ -45,8 +47,7 @@ class CurlStub(object):
         self.performed = True
 
 
-class CurlManyStub(object):
-
+class CurlManyStub:
     def __init__(self, url_results):
         self.curls = {}
         for url in url_results:
@@ -58,7 +59,9 @@ class CurlManyStub(object):
                 body = result[0]
                 http_code = result[1]
             self.curls[url] = CurlStub(
-                result=body, infos={pycurl.HTTP_CODE: http_code})
+                result=body,
+                infos={pycurl.HTTP_CODE: http_code},
+            )
 
         # Use thread local storage to keep the current CurlStub since
         # CurlManyStub is passed to multiple threads, but the state needs to be
@@ -79,91 +82,108 @@ class CurlManyStub(object):
             # want to keep it like this. But when we set the value for pycurl
             # option we already have the encoded bytes object, that's why we
             # have to decode again.
-            self._local.current = self.curls[value.decode('ascii')]
+            self._local.current = self.curls[value.decode("ascii")]
         self._local.current.setopt(option, value)
 
     def perform(self):
         self._local.current.perform()
 
 
-class Any(object):
-
+class Any:
     def __eq__(self, other):
         return True
 
 
-class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
-                unittest.TestCase):
-
+class FetchTest(
+    testing.FSTestCase,
+    testing.TwistedTestCase,
+    unittest.TestCase,
+):
     def test_basic(self):
         curl = CurlStub(b"result")
         result = fetch("http://example.com", curl=curl)
         self.assertEqual(result, b"result")
-        self.assertEqual(curl.options,
-                         {pycurl.URL: b"http://example.com",
-                          pycurl.FOLLOWLOCATION: 1,
-                          pycurl.MAXREDIRS: 5,
-                          pycurl.CONNECTTIMEOUT: 30,
-                          pycurl.LOW_SPEED_LIMIT: 1,
-                          pycurl.LOW_SPEED_TIME: 600,
-                          pycurl.NOSIGNAL: 1,
-                          pycurl.WRITEFUNCTION: Any(),
-                          pycurl.DNS_CACHE_TIMEOUT: 0,
-                          pycurl.ENCODING: b"gzip,deflate"})
+        self.assertEqual(
+            curl.options,
+            {
+                pycurl.URL: b"http://example.com",
+                pycurl.FOLLOWLOCATION: 1,
+                pycurl.MAXREDIRS: 5,
+                pycurl.CONNECTTIMEOUT: 30,
+                pycurl.LOW_SPEED_LIMIT: 1,
+                pycurl.LOW_SPEED_TIME: 600,
+                pycurl.NOSIGNAL: 1,
+                pycurl.WRITEFUNCTION: Any(),
+                pycurl.DNS_CACHE_TIMEOUT: 0,
+                pycurl.ENCODING: b"gzip,deflate",
+            },
+        )
 
     def test_post(self):
         curl = CurlStub(b"result")
         result = fetch("http://example.com", post=True, curl=curl)
         self.assertEqual(result, b"result")
-        self.assertEqual(curl.options,
-                         {pycurl.URL: b"http://example.com",
-                          pycurl.FOLLOWLOCATION: 1,
-                          pycurl.MAXREDIRS: 5,
-                          pycurl.CONNECTTIMEOUT: 30,
-                          pycurl.LOW_SPEED_LIMIT: 1,
-                          pycurl.LOW_SPEED_TIME: 600,
-                          pycurl.NOSIGNAL: 1,
-                          pycurl.WRITEFUNCTION: Any(),
-                          pycurl.POST: True,
-                          pycurl.DNS_CACHE_TIMEOUT: 0,
-                          pycurl.ENCODING: b"gzip,deflate"})
+        self.assertEqual(
+            curl.options,
+            {
+                pycurl.URL: b"http://example.com",
+                pycurl.FOLLOWLOCATION: 1,
+                pycurl.MAXREDIRS: 5,
+                pycurl.CONNECTTIMEOUT: 30,
+                pycurl.LOW_SPEED_LIMIT: 1,
+                pycurl.LOW_SPEED_TIME: 600,
+                pycurl.NOSIGNAL: 1,
+                pycurl.WRITEFUNCTION: Any(),
+                pycurl.POST: True,
+                pycurl.DNS_CACHE_TIMEOUT: 0,
+                pycurl.ENCODING: b"gzip,deflate",
+            },
+        )
 
     def test_post_data(self):
         curl = CurlStub(b"result")
         result = fetch("http://example.com", post=True, data="data", curl=curl)
         self.assertEqual(result, b"result")
         self.assertEqual(curl.options[pycurl.READFUNCTION](), b"data")
-        self.assertEqual(curl.options,
-                         {pycurl.URL: b"http://example.com",
-                          pycurl.FOLLOWLOCATION: 1,
-                          pycurl.MAXREDIRS: 5,
-                          pycurl.CONNECTTIMEOUT: 30,
-                          pycurl.LOW_SPEED_LIMIT: 1,
-                          pycurl.LOW_SPEED_TIME: 600,
-                          pycurl.NOSIGNAL: 1,
-                          pycurl.WRITEFUNCTION: Any(),
-                          pycurl.POST: True,
-                          pycurl.POSTFIELDSIZE: 4,
-                          pycurl.READFUNCTION: Any(),
-                          pycurl.DNS_CACHE_TIMEOUT: 0,
-                          pycurl.ENCODING: b"gzip,deflate"})
+        self.assertEqual(
+            curl.options,
+            {
+                pycurl.URL: b"http://example.com",
+                pycurl.FOLLOWLOCATION: 1,
+                pycurl.MAXREDIRS: 5,
+                pycurl.CONNECTTIMEOUT: 30,
+                pycurl.LOW_SPEED_LIMIT: 1,
+                pycurl.LOW_SPEED_TIME: 600,
+                pycurl.NOSIGNAL: 1,
+                pycurl.WRITEFUNCTION: Any(),
+                pycurl.POST: True,
+                pycurl.POSTFIELDSIZE: 4,
+                pycurl.READFUNCTION: Any(),
+                pycurl.DNS_CACHE_TIMEOUT: 0,
+                pycurl.ENCODING: b"gzip,deflate",
+            },
+        )
 
     def test_cainfo(self):
         curl = CurlStub(b"result")
         result = fetch("https://example.com", cainfo="cainfo", curl=curl)
         self.assertEqual(result, b"result")
-        self.assertEqual(curl.options,
-                         {pycurl.URL: b"https://example.com",
-                          pycurl.FOLLOWLOCATION: 1,
-                          pycurl.MAXREDIRS: 5,
-                          pycurl.CONNECTTIMEOUT: 30,
-                          pycurl.LOW_SPEED_LIMIT: 1,
-                          pycurl.LOW_SPEED_TIME: 600,
-                          pycurl.NOSIGNAL: 1,
-                          pycurl.WRITEFUNCTION: Any(),
-                          pycurl.CAINFO: b"cainfo",
-                          pycurl.DNS_CACHE_TIMEOUT: 0,
-                          pycurl.ENCODING: b"gzip,deflate"})
+        self.assertEqual(
+            curl.options,
+            {
+                pycurl.URL: b"https://example.com",
+                pycurl.FOLLOWLOCATION: 1,
+                pycurl.MAXREDIRS: 5,
+                pycurl.CONNECTTIMEOUT: 30,
+                pycurl.LOW_SPEED_LIMIT: 1,
+                pycurl.LOW_SPEED_TIME: 600,
+                pycurl.NOSIGNAL: 1,
+                pycurl.WRITEFUNCTION: Any(),
+                pycurl.CAINFO: b"cainfo",
+                pycurl.DNS_CACHE_TIMEOUT: 0,
+                pycurl.ENCODING: b"gzip,deflate",
+            },
+        )
 
     def test_cainfo_on_http(self):
         curl = CurlStub(b"result")
@@ -173,38 +193,53 @@ class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
 
     def test_headers(self):
         curl = CurlStub(b"result")
-        result = fetch("http://example.com",
-                       headers={"a": "1", "b": "2"}, curl=curl)
+        result = fetch(
+            "http://example.com",
+            headers={"a": "1", "b": "2"},
+            curl=curl,
+        )
         self.assertEqual(result, b"result")
-        self.assertEqual(curl.options,
-                         {pycurl.URL: b"http://example.com",
-                          pycurl.FOLLOWLOCATION: 1,
-                          pycurl.MAXREDIRS: 5,
-                          pycurl.CONNECTTIMEOUT: 30,
-                          pycurl.LOW_SPEED_LIMIT: 1,
-                          pycurl.LOW_SPEED_TIME: 600,
-                          pycurl.NOSIGNAL: 1,
-                          pycurl.WRITEFUNCTION: Any(),
-                          pycurl.HTTPHEADER: ["a: 1", "b: 2"],
-                          pycurl.DNS_CACHE_TIMEOUT: 0,
-                          pycurl.ENCODING: b"gzip,deflate"})
+        self.assertEqual(
+            curl.options,
+            {
+                pycurl.URL: b"http://example.com",
+                pycurl.FOLLOWLOCATION: 1,
+                pycurl.MAXREDIRS: 5,
+                pycurl.CONNECTTIMEOUT: 30,
+                pycurl.LOW_SPEED_LIMIT: 1,
+                pycurl.LOW_SPEED_TIME: 600,
+                pycurl.NOSIGNAL: 1,
+                pycurl.WRITEFUNCTION: Any(),
+                pycurl.HTTPHEADER: ["a: 1", "b: 2"],
+                pycurl.DNS_CACHE_TIMEOUT: 0,
+                pycurl.ENCODING: b"gzip,deflate",
+            },
+        )
 
     def test_timeouts(self):
         curl = CurlStub(b"result")
-        result = fetch("http://example.com", connect_timeout=5,
-                       total_timeout=30, curl=curl)
+        result = fetch(
+            "http://example.com",
+            connect_timeout=5,
+            total_timeout=30,
+            curl=curl,
+        )
         self.assertEqual(result, b"result")
-        self.assertEqual(curl.options,
-                         {pycurl.URL: b"http://example.com",
-                          pycurl.FOLLOWLOCATION: 1,
-                          pycurl.MAXREDIRS: 5,
-                          pycurl.CONNECTTIMEOUT: 5,
-                          pycurl.LOW_SPEED_LIMIT: 1,
-                          pycurl.LOW_SPEED_TIME: 30,
-                          pycurl.NOSIGNAL: 1,
-                          pycurl.WRITEFUNCTION: Any(),
-                          pycurl.DNS_CACHE_TIMEOUT: 0,
-                          pycurl.ENCODING: b"gzip,deflate"})
+        self.assertEqual(
+            curl.options,
+            {
+                pycurl.URL: b"http://example.com",
+                pycurl.FOLLOWLOCATION: 1,
+                pycurl.MAXREDIRS: 5,
+                pycurl.CONNECTTIMEOUT: 5,
+                pycurl.LOW_SPEED_LIMIT: 1,
+                pycurl.LOW_SPEED_TIME: 30,
+                pycurl.NOSIGNAL: 1,
+                pycurl.WRITEFUNCTION: Any(),
+                pycurl.DNS_CACHE_TIMEOUT: 0,
+                pycurl.ENCODING: b"gzip,deflate",
+            },
+        )
 
     def test_unicode(self):
         """
@@ -212,7 +247,7 @@ class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
         passing it to curl.
         """
         curl = CurlStub(b"result")
-        result = fetch(u"http://example.com", curl=curl)
+        result = fetch("http://example.com", curl=curl)
         self.assertEqual(result, b"result")
         self.assertEqual(curl.options[pycurl.URL], b"http://example.com")
         self.assertTrue(isinstance(curl.options[pycurl.URL], bytes))
@@ -228,12 +263,16 @@ class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
             self.fail("HTTPCodeError not raised")
 
     def test_http_error_str(self):
-        self.assertEqual(str(HTTPCodeError(501, "")),
-                         "Server returned HTTP code 501")
+        self.assertEqual(
+            str(HTTPCodeError(501, "")),
+            "Server returned HTTP code 501",
+        )
 
     def test_http_error_repr(self):
-        self.assertEqual(repr(HTTPCodeError(501, "")),
-                         "<HTTPCodeError http_code=501>")
+        self.assertEqual(
+            repr(HTTPCodeError(501, "")),
+            "<HTTPCodeError http_code=501>",
+        )
 
     def test_pycurl_error(self):
         curl = CurlStub(error=pycurl.error(60, "pycurl error"))
@@ -247,41 +286,50 @@ class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
 
     def test_pycurl_insecure(self):
         curl = CurlStub(b"result")
-        result = fetch("http://example.com/get-ca-cert", curl=curl,
-                       insecure=True)
+        result = fetch(
+            "http://example.com/get-ca-cert",
+            curl=curl,
+            insecure=True,
+        )
         self.assertEqual(result, b"result")
-        self.assertEqual(curl.options,
-                         {pycurl.URL: b"http://example.com/get-ca-cert",
-                          pycurl.FOLLOWLOCATION: 1,
-                          pycurl.MAXREDIRS: 5,
-                          pycurl.CONNECTTIMEOUT: 30,
-                          pycurl.LOW_SPEED_LIMIT: 1,
-                          pycurl.LOW_SPEED_TIME: 600,
-                          pycurl.NOSIGNAL: 1,
-                          pycurl.WRITEFUNCTION: Any(),
-                          pycurl.SSL_VERIFYPEER: False,
-                          pycurl.DNS_CACHE_TIMEOUT: 0,
-                          pycurl.ENCODING: b"gzip,deflate"})
+        self.assertEqual(
+            curl.options,
+            {
+                pycurl.URL: b"http://example.com/get-ca-cert",
+                pycurl.FOLLOWLOCATION: 1,
+                pycurl.MAXREDIRS: 5,
+                pycurl.CONNECTTIMEOUT: 30,
+                pycurl.LOW_SPEED_LIMIT: 1,
+                pycurl.LOW_SPEED_TIME: 600,
+                pycurl.NOSIGNAL: 1,
+                pycurl.WRITEFUNCTION: Any(),
+                pycurl.SSL_VERIFYPEER: False,
+                pycurl.DNS_CACHE_TIMEOUT: 0,
+                pycurl.ENCODING: b"gzip,deflate",
+            },
+        )
 
     def test_pycurl_error_str(self):
-        self.assertEqual(str(PyCurlError(60, "pycurl error")),
-                         "Error 60: pycurl error")
+        self.assertEqual(
+            str(PyCurlError(60, "pycurl error")),
+            "Error 60: pycurl error",
+        )
 
     def test_pycurl_error_repr(self):
-        self.assertEqual(repr(PyCurlError(60, "pycurl error")),
-                         "<PyCurlError args=(60, 'pycurl error')>")
+        self.assertEqual(
+            repr(PyCurlError(60, "pycurl error")),
+            "<PyCurlError args=(60, 'pycurl error')>",
+        )
 
     def test_pycurl_follow_true(self):
         curl = CurlStub(b"result")
-        result = fetch("http://example.com", curl=curl,
-                       follow=True)
+        result = fetch("http://example.com", curl=curl, follow=True)
         self.assertEqual(result, b"result")
         self.assertEqual(1, curl.options[pycurl.FOLLOWLOCATION])
 
     def test_pycurl_follow_false(self):
         curl = CurlStub(b"result")
-        result = fetch("http://example.com", curl=curl,
-                       follow=False)
+        result = fetch("http://example.com", curl=curl, follow=False)
         self.assertEqual(result, b"result")
         self.assertNotIn(pycurl.FOLLOWLOCATION, curl.options.keys())
 
@@ -289,7 +337,10 @@ class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
         """If provided, the user-agent is set in the request."""
         curl = CurlStub(b"result")
         result = fetch(
-            "http://example.com", curl=curl, user_agent="user-agent")
+            "http://example.com",
+            curl=curl,
+            user_agent="user-agent",
+        )
         self.assertEqual(result, b"result")
         self.assertEqual(b"user-agent", curl.options[pycurl.USERAGENT])
 
@@ -299,34 +350,35 @@ class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
         proxy = "http://my.little.proxy"
         result = fetch("http://example.com", curl=curl, proxy=proxy)
         self.assertEqual(b"result", result)
-        self.assertEqual(proxy.encode('ascii'), curl.options[pycurl.PROXY])
+        self.assertEqual(proxy.encode("ascii"), curl.options[pycurl.PROXY])
 
     def test_create_curl(self):
         curls = []
 
-        def pycurl_Curl():
+        def pycurl_curl():
             curl = CurlStub(b"result")
             curls.append(curl)
             return curl
-        Curl = pycurl.Curl
-        try:
-            pycurl.Curl = pycurl_Curl
-            result = fetch("http://example.com")
-            curl = curls[0]
-            self.assertEqual(result, b"result")
-            self.assertEqual(curl.options,
-                             {pycurl.URL: b"http://example.com",
-                              pycurl.FOLLOWLOCATION: 1,
-                              pycurl.MAXREDIRS: 5,
-                              pycurl.CONNECTTIMEOUT: 30,
-                              pycurl.LOW_SPEED_LIMIT: 1,
-                              pycurl.LOW_SPEED_TIME: 600,
-                              pycurl.NOSIGNAL: 1,
-                              pycurl.WRITEFUNCTION: Any(),
-                              pycurl.DNS_CACHE_TIMEOUT: 0,
-                              pycurl.ENCODING: b"gzip,deflate"})
-        finally:
-            pycurl.Curl = Curl
+
+        pycurl.Curl = pycurl_curl
+        result = fetch("http://example.com")
+        curl = curls[0]
+        self.assertEqual(result, b"result")
+        self.assertEqual(
+            curl.options,
+            {
+                pycurl.URL: b"http://example.com",
+                pycurl.FOLLOWLOCATION: 1,
+                pycurl.MAXREDIRS: 5,
+                pycurl.CONNECTTIMEOUT: 30,
+                pycurl.LOW_SPEED_LIMIT: 1,
+                pycurl.LOW_SPEED_TIME: 600,
+                pycurl.NOSIGNAL: 1,
+                pycurl.WRITEFUNCTION: Any(),
+                pycurl.DNS_CACHE_TIMEOUT: 0,
+                pycurl.ENCODING: b"gzip,deflate",
+            },
+        )
 
     def test_async_fetch(self):
         curl = CurlStub(b"result")
@@ -334,6 +386,7 @@ class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
 
         def got_result(result):
             self.assertEqual(result, b"result")
+
         return d.addCallback(got_result)
 
     def test_async_fetch_with_error(self):
@@ -344,6 +397,7 @@ class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
             self.assertEqual(failure.value.http_code, 501)
             self.assertEqual(failure.value.body, b"result")
             return failure
+
         d.addErrback(got_error)
         self.assertFailure(d, HTTPCodeError)
         return d
@@ -354,8 +408,7 @@ class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
         C{DeferredList} firing its callback when all the URLs have
         successfully completed.
         """
-        url_results = {"http://good/": b"good",
-                       "http://better/": b"better"}
+        url_results = {"http://good/": b"good", "http://better/": b"better"}
 
         def callback(result, url):
             self.assertIn(result, url_results.values())
@@ -366,8 +419,12 @@ class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
             self.fail()
 
         curl = CurlManyStub(url_results)
-        d = fetch_many_async(url_results.keys(), callback=callback,
-                             errback=errback, curl=curl)
+        d = fetch_many_async(
+            url_results.keys(),
+            callback=callback,
+            errback=errback,
+            curl=curl,
+        )
 
         def completed(result):
             self.assertEqual(url_results, {})
@@ -378,9 +435,11 @@ class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
         """
         L{fetch_many_async} aborts as soon as one URL fails.
         """
-        url_results = {"http://right/": b"right",
-                       "http://wrong/": (b"wrong", 501),
-                       "http://impossible/": b"impossible"}
+        url_results = {
+            "http://right/": b"right",
+            "http://wrong/": (b"wrong", 501),
+            "http://impossible/": b"impossible",
+        }
         failed_urls = []
 
         def errback(failure, url):
@@ -391,12 +450,17 @@ class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
 
         curl = CurlManyStub(url_results)
         urls = ["http://right/", "http://wrong/", "http://impossible/"]
-        result = fetch_many_async(urls, callback=None,
-                                  errback=errback, curl=curl)
+        result = fetch_many_async(
+            urls,
+            callback=None,
+            errback=errback,
+            curl=curl,
+        )
 
         def check_failure(failure):
-            self.assertTrue(isinstance(failure.subFailure.value,
-                                       HTTPCodeError))
+            self.assertTrue(
+                isinstance(failure.subFailure.value, HTTPCodeError),
+            )
             self.assertEqual(failed_urls, ["http://wrong/"])
 
         self.assertFailure(result, FirstError)
@@ -409,16 +473,20 @@ class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
         """
         self.assertEqual(url_to_filename("http://some/file"), "file")
         self.assertEqual(url_to_filename("http://some/file/"), "file")
-        self.assertEqual(url_to_filename("http://some/file", directory="dir"),
-                         os.path.join("dir", "file"))
+        self.assertEqual(
+            url_to_filename("http://some/file", directory="dir"),
+            os.path.join("dir", "file"),
+        )
 
     def test_fetch_to_files(self):
         """
         L{fetch_to_files} fetches a list of URLs and save their content
         in the given directory.
         """
-        url_results = {"http://good/file": b"file",
-                       "http://even/better-file": b"better-file"}
+        url_results = {
+            "http://good/file": b"file",
+            "http://even/better-file": b"better-file",
+        }
         directory = self.makeDir()
         curl = CurlManyStub(url_results)
 
@@ -427,7 +495,7 @@ class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
         def check_files(ignored):
             for url, result in url_results.items():
                 filename = url.rstrip("/").split("/")[-1]
-                fd = open(os.path.join(directory, filename), 'rb')
+                fd = open(os.path.join(directory, filename), "rb")
                 self.assertEqual(fd.read(), result)
                 fd.close()
 
@@ -455,22 +523,33 @@ class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
         L{fetch_to_files} optionally logs an error message as soon as one URL
         fails, and aborts.
         """
-        url_results = {"http://im/right": b"right",
-                       "http://im/wrong": (b"wrong", 404),
-                       "http://im/not": b"not"}
+        url_results = {
+            "http://im/right": b"right",
+            "http://im/wrong": (b"wrong", 404),
+            "http://im/not": b"not",
+        }
         directory = self.makeDir()
         messages = []
-        logger = (lambda message: messages.append(message))
+
+        def logger(message):
+            return messages.append(message)
+
         curl = CurlManyStub(url_results)
 
-        result = fetch_to_files(url_results.keys(), directory, logger=logger,
-                                curl=curl)
+        result = fetch_to_files(
+            url_results.keys(),
+            directory,
+            logger=logger,
+            curl=curl,
+        )
 
         def check_messages(failure):
             self.assertEqual(len(messages), 1)
-            self.assertEqual(messages[0],
-                             "Couldn't fetch file from http://im/wrong "
-                             "(Server returned HTTP code 404)")
+            self.assertEqual(
+                messages[0],
+                "Couldn't fetch file from http://im/wrong "
+                "(Server returned HTTP code 404)",
+            )
             messages.pop()
 
         def check_files(ignored):
@@ -494,9 +573,13 @@ class FetchTest(testing.FSTestCase, testing.TwistedTestCase,
 
         def check_error(failure):
             error = str(failure.value.subFailure.value)
-            self.assertEqual(error,
-                             ("[Errno 2] No such file or directory: "
-                              "'i/dont/exist/right'"))
+            self.assertEqual(
+                error,
+                (
+                    "[Errno 2] No such file or directory: "
+                    "'i/dont/exist/right'"
+                ),
+            )
             self.assertFalse(os.path.exists(os.path.join(directory, "right")))
 
         result.addErrback(check_error)
