@@ -1,10 +1,9 @@
+import os
+
 from twisted.internet.defer import succeed
 
-from landscape.lib.process import ProcessInformation
-
-
-class Processes(object):
 
+class Processes:
     def __init__(self, proc_dir="/proc"):
         self._proc_dir = proc_dir
 
@@ -14,16 +13,27 @@ class Processes(object):
     def run(self):
         num_processes = 0
         num_zombies = 0
-        info = ProcessInformation(proc_dir=self._proc_dir)
-        for process_info in info.get_all_process_info():
+        for pid in os.listdir(self._proc_dir):
+            if not pid.isdigit():
+                continue
+            status_path = os.path.join(self._proc_dir, pid, "stat")
+
+            try:
+                with open(status_path, "rb") as fd:
+                    data = fd.read()
+            except IOError:
+                continue
+
             num_processes += 1
-            if process_info["state"] == "Z":
+
+            if b"Z" == data.split(b" ", 3)[2]:
                 num_zombies += 1
+
         if num_zombies:
             if num_zombies == 1:
                 msg = "There is 1 zombie process."
             else:
-                msg = "There are %d zombie processes." % (num_zombies,)
+                msg = f"There are {num_zombies:d} zombie processes."
             self._sysinfo.add_note(msg)
         self._sysinfo.add_header("Processes", str(num_processes))
         return succeed(None)
