@@ -1,28 +1,30 @@
-from logging.handlers import RotatingFileHandler
-from logging import getLogger
 import os
 import unittest
+from logging import getLogger
+from logging.handlers import RotatingFileHandler
+from unittest import mock
 
-import mock
 from twisted.internet.defer import Deferred
 
 from landscape.lib.fs import create_text_file
-from landscape.lib.testing import (
-        ConfigTestCase, TwistedTestCase, HelperTestCase, StandardIOHelper)
-
-from landscape.sysinfo.deployment import (
-    SysInfoConfiguration, ALL_PLUGINS, run, setup_logging,
-    get_landscape_log_directory)
-from landscape.sysinfo.testplugin import TestPlugin
-from landscape.sysinfo.sysinfo import SysInfoPluginRegistry
-from landscape.sysinfo.load import Load
+from landscape.lib.testing import ConfigTestCase
+from landscape.lib.testing import HelperTestCase
+from landscape.lib.testing import StandardIOHelper
+from landscape.lib.testing import TwistedTestCase
+from landscape.sysinfo.deployment import ALL_PLUGINS
+from landscape.sysinfo.deployment import get_landscape_log_directory
+from landscape.sysinfo.deployment import run
+from landscape.sysinfo.deployment import setup_logging
+from landscape.sysinfo.deployment import SysInfoConfiguration
 from landscape.sysinfo.landscapelink import LandscapeLink
+from landscape.sysinfo.load import Load
+from landscape.sysinfo.sysinfo import SysInfoPluginRegistry
+from landscape.sysinfo.testplugin import TestPlugin
 
 
 class DeploymentTest(ConfigTestCase, unittest.TestCase):
-
     def setUp(self):
-        super(DeploymentTest, self).setUp()
+        super().setUp()
 
         class TestConfiguration(SysInfoConfiguration):
             default_config_filenames = [self.makeFile("")]
@@ -30,8 +32,9 @@ class DeploymentTest(ConfigTestCase, unittest.TestCase):
         self.configuration = TestConfiguration()
 
     def test_get_plugins(self):
-        self.configuration.load(["--sysinfo-plugins", "Load,TestPlugin",
-                                 "-d", self.makeDir()])
+        self.configuration.load(
+            ["--sysinfo-plugins", "Load,TestPlugin", "-d", self.makeDir()],
+        )
         plugins = self.configuration.get_plugins()
         self.assertEqual(len(plugins), 2)
         self.assertTrue(isinstance(plugins[0], Load))
@@ -50,8 +53,9 @@ class DeploymentTest(ConfigTestCase, unittest.TestCase):
 
     def test_exclude_plugins(self):
         exclude = ",".join(x for x in ALL_PLUGINS if x != "Load")
-        self.configuration.load(["--exclude-sysinfo-plugins", exclude,
-                                 "-d", self.makeDir()])
+        self.configuration.load(
+            ["--exclude-sysinfo-plugins", exclude, "-d", self.makeDir()],
+        )
         plugins = self.configuration.get_plugins()
         self.assertEqual(len(plugins), 1)
         self.assertTrue(isinstance(plugins[0], Load))
@@ -65,7 +69,7 @@ class DeploymentTest(ConfigTestCase, unittest.TestCase):
         self.assertTrue(isinstance(plugins[0], TestPlugin))
 
 
-class FakeReactor(object):
+class FakeReactor:
     """
     Something that's simpler and more reusable than a bunch of mocked objects.
     """
@@ -75,31 +79,35 @@ class FakeReactor(object):
         self.scheduled_calls = []
         self.running = False
 
-    def callWhenRunning(self, callable):
+    def callWhenRunning(self, callable):  # noqa: N802
         self.queued_calls.append(callable)
 
     def run(self):
         self.running = True
 
-    def callLater(self, seconds, callable, *args, **kwargs):
+    def callLater(self, seconds, callable, *args, **kwargs):  # noqa: N802
         self.scheduled_calls.append((seconds, callable, args, kwargs))
 
     def stop(self):
         self.running = False
 
 
-class RunTest(HelperTestCase, ConfigTestCase, TwistedTestCase,
-              unittest.TestCase):
+class RunTest(
+    HelperTestCase,
+    ConfigTestCase,
+    TwistedTestCase,
+    unittest.TestCase,
+):
 
     helpers = [StandardIOHelper]
 
     def setUp(self):
-        super(RunTest, self).setUp()
+        super().setUp()
         self._old_filenames = SysInfoConfiguration.default_config_filenames
         SysInfoConfiguration.default_config_filenames = [self.makeFile("")]
 
     def tearDown(self):
-        super(RunTest, self).tearDown()
+        super().tearDown()
         SysInfoConfiguration.default_config_filenames = self._old_filenames
         logger = getLogger("landscape-sysinfo")
         for handler in logger.handlers[:]:
@@ -112,23 +120,29 @@ class RunTest(HelperTestCase, ConfigTestCase, TwistedTestCase,
 
         self.assertEqual(current_instance.has_run, True)
         sysinfo = current_instance.sysinfo
-        self.assertEqual(sysinfo.get_headers(),
-                         [("Test header", "Test value")])
+        self.assertEqual(
+            sysinfo.get_headers(),
+            [("Test header", "Test value")],
+        )
         self.assertEqual(sysinfo.get_notes(), ["Test note"])
         self.assertEqual(sysinfo.get_footnotes(), ["Test footnote"])
 
     @mock.patch("landscape.sysinfo.deployment.format_sysinfo")
     def test_format_sysinfo_gets_correct_information(self, format_sysinfo):
-        run(["--sysinfo-plugins", "TestPlugin"])
+        run(["--sysinfo-plugins", "TestPlugin", "--width", "100"])
         format_sysinfo.assert_called_once_with(
             [("Test header", "Test value")],
-            ["Test note"], ["Test footnote"],
-            indent="  ")
+            ["Test note"],
+            ["Test footnote"],
+            width=100,
+            indent="  ",
+        )
 
     def test_format_sysinfo_output_is_printed(self):
         with mock.patch(
-                "landscape.sysinfo.deployment.format_sysinfo",
-                return_value="Hello there!") as format_sysinfo:
+            "landscape.sysinfo.deployment.format_sysinfo",
+            return_value="Hello there!",
+        ) as format_sysinfo:
             run(["--sysinfo-plugins", "TestPlugin"])
 
         self.assertTrue(format_sysinfo.called)
@@ -148,6 +162,7 @@ class RunTest(HelperTestCase, ConfigTestCase, TwistedTestCase,
         def wrapped_sysinfo_run(*args, **kwargs):
             original_sysinfo_run(*args, **kwargs)
             return deferred
+
         sysinfo.run = mock.Mock(side_effect=wrapped_sysinfo_run)
 
         run(["--sysinfo-plugins", "TestPlugin"], sysinfo=sysinfo)
@@ -193,7 +208,8 @@ class RunTest(HelperTestCase, ConfigTestCase, TwistedTestCase,
 
         self.assertEqual(
             self.stdout.getvalue(),
-            "  Test header: Test value\n\n  => Test note\n\n  Test footnote\n")
+            "  Test header: Test value\n\n  => Test note\n\n  Test footnote\n",
+        )
         return d
 
     def test_stop_scheduled_in_callback(self):
@@ -216,8 +232,11 @@ class RunTest(HelperTestCase, ConfigTestCase, TwistedTestCase,
         reactor = FakeReactor()
         sysinfo = SysInfoPluginRegistry()
         sysinfo.run = lambda: 1 / 0
-        d = run(["--sysinfo-plugins", "TestPlugin"], reactor=reactor,
-                sysinfo=sysinfo)
+        d = run(
+            ["--sysinfo-plugins", "TestPlugin"],
+            reactor=reactor,
+            sysinfo=sysinfo,
+        )
 
         for x in reactor.queued_calls:
             x()
@@ -230,8 +249,10 @@ class RunTest(HelperTestCase, ConfigTestCase, TwistedTestCase,
         If landscape-sysinfo is running as a non-privileged user the
         log directory is stored in their home directory.
         """
-        self.assertEqual(get_landscape_log_directory(),
-                         os.path.expanduser("~/.landscape"))
+        self.assertEqual(
+            get_landscape_log_directory(),
+            os.path.expanduser("~/.landscape"),
+        )
 
     def test_get_landscape_log_directory_privileged(self):
         """
@@ -240,7 +261,9 @@ class RunTest(HelperTestCase, ConfigTestCase, TwistedTestCase,
         """
         with mock.patch("os.getuid", return_value=0) as uid_mock:
             self.assertEqual(
-                get_landscape_log_directory(), "/var/log/landscape")
+                get_landscape_log_directory(),
+                "/var/log/landscape",
+            )
             uid_mock.assert_called_once_with()
 
     def test_wb_logging_setup(self):
@@ -261,11 +284,21 @@ class RunTest(HelperTestCase, ConfigTestCase, TwistedTestCase,
         self.assertFalse(logger.propagate)
 
     def test_setup_logging_logs_to_var_log_if_run_as_root(self):
-        with mock.patch.object(os, "getuid", return_value=0) as mock_getuid, \
-                mock.patch.object(
-                    os.path, "isdir", return_value=False) as mock_isdir, \
-                mock.patch.object(os, "mkdir") as mock_mkdir, \
-                mock.patch("logging.open", create=True) as mock_open:
+        with mock.patch.object(
+            os,
+            "getuid",
+            return_value=0,
+        ) as mock_getuid, mock.patch.object(
+            os.path,
+            "isdir",
+            return_value=False,
+        ) as mock_isdir, mock.patch.object(
+            os,
+            "mkdir",
+        ) as mock_mkdir, mock.patch(
+            "logging.open",
+            create=True,
+        ) as mock_open:
             logger = getLogger("landscape-sysinfo")
             self.assertEqual(logger.handlers, [])
 
@@ -276,12 +309,14 @@ class RunTest(HelperTestCase, ConfigTestCase, TwistedTestCase,
         mock_mkdir.assert_called_with("/var/log/landscape")
         self.assertEqual(
             mock_open.call_args_list[0][0],
-            ("/var/log/landscape/sysinfo.log", "a")
+            ("/var/log/landscape/sysinfo.log", "a"),
         )
         handler = logger.handlers[0]
         self.assertTrue(isinstance(handler, RotatingFileHandler))
-        self.assertEqual(handler.baseFilename,
-                         "/var/log/landscape/sysinfo.log")
+        self.assertEqual(
+            handler.baseFilename,
+            "/var/log/landscape/sysinfo.log",
+        )
 
     def test_create_log_dir(self):
         log_dir = self.makeFile()
@@ -291,17 +326,23 @@ class RunTest(HelperTestCase, ConfigTestCase, TwistedTestCase,
 
     def test_run_sets_up_logging(self):
         with mock.patch(
-                "landscape.sysinfo.deployment"
-                ".setup_logging") as setup_logging_mock:
+            "landscape.sysinfo.deployment.setup_logging",
+        ) as setup_logging_mock:
             run(["--sysinfo-plugins", "TestPlugin"])
         setup_logging_mock.assert_called_once_with()
 
     def test_run_setup_logging_exits_gracefully(self):
         io_error = IOError("Read-only filesystem.")
         with mock.patch(
-                "landscape.sysinfo.deployment.setup_logging",
-                side_effect=io_error):
+            "landscape.sysinfo.deployment.setup_logging",
+            side_effect=io_error,
+        ):
             error = self.assertRaises(
-                SystemExit, run, ["--sysinfo-plugins", "TestPlugin"])
+                SystemExit,
+                run,
+                ["--sysinfo-plugins", "TestPlugin"],
+            )
         self.assertEqual(
-            error.code, "Unable to setup logging. Read-only filesystem.")
+            error.code,
+            "Unable to setup logging. Read-only filesystem.",
+        )
